/**********************************************************************/
/* Before you run this program:                                       */
/*  - create root folder for XML Map files and output data            */
/*    Example:                                                        */
/*         c:\public\kiva                                             */
/*         c:\public\kiva\xmlMap (for *.map files)                    */
/*         c:\public\kiva\datasets (for output data)                  */ 
/*  - download data from http://s3.kiva.org/snapshots/kiva_ds_xml.zip */
/*  - unzip files into the root folder.                               */
/*    (Will have subfolders for lenders and loans subfolders          */
/*    Example:                                                        */
/*         c:\public\kiva\lenders                                     */
/*         c:\public\kiva\loans                                       */
/*  - Update the follow macro variables with the folder name,         */
/*    file count for lender XML files, and file count for loan XML    */
/*    files.                                                          */
/**********************************************************************/
%let KivaRoot = C:\Public\Kiva;
%let lenderCount = 577;
%let loanCount = 166;

%macro getLenders();
	%do i=1 %to &lenderCount;
		filename  SXLELIB "&KivaRoot\lenders\&i..xml";
		filename  SXLEMAP "&KivaRoot\xmlMap\KivaLenderMap.map";
		libname   SXLELIB xml xmlmap=SXLEMAP access=READONLY;
		libname kiva "&KivaRoot\datasets";

		DATA kiva.lender&i;
			sysecho "Processing lender file: &i";
			SET SXLELIB.lender;
		run;

	%end;

	data kiva.lenders;
		sysecho "Collating Lender data";
		set kiva.lender1-kiva.lender&lenderCount.;
	run;

	proc sql noprint;
		%do i=1 %to &lenderCount;
			drop table kiva.lender&i.;
		%end;
	quit;

%mend;

%getLenders();

%macro getLoans();
	%do i=1 %to &loanCount;
		filename  SXLELIB "&KivaRoot\loans\&i..xml";
		filename  SXLEMAP "&KivaRoot\xmlMap\KivaLoanMap.map";
		libname   SXLELIB xml xmlmap=SXLEMAP access=READONLY;
		libname kiva "&KivaRoot\datasets";

		DATA kiva.loan&i;
			sysecho "Processing loan file: &i";
			SET SXLELIB.loan;
		run;

	%end;

	data kiva.loans;
		sysecho "Collating Loan data";
		set kiva.loan1-kiva.loan&loanCount.;
		by id;
		if first.id;
	run;

	proc sql noprint;
		%do i=1 %to &loanCount;
			drop table kiva.loan&i.;
		%end;
	quit;

%mend;

%getLoans();

proc sql noprint;
  select count(*)  into :numMen from kiva.loans 
    where gender="M" ;

  select count(*)  into :numWomen from kiva.loans 
    where gender="F";
quit;
  
ods graphics / height=400 width=1000;
title "Distribution of Funded Amount per loan";
footnote1 "Loans to Men: %sysfunc(putn(&numMen,comma12.))";
footnote2 "Loans to Women: %sysfunc(putn(&numWomen,comma10.))";
proc sgpanel data=kiva.loans;
	format funded_amount dollar10.;
  panelby gender / columns=1 layout=rowlattice novarname;
  hbox funded_amount / boxwidth=1.0;
run;
title; footnote;
